import React, { memo, useState, useEffect } from 'react'
import array from 'lodash/array'
import ServiceProductChart from './ServiceProductChart'

const ServiceInfo = ({ fields, tasks }) => {
  const [services, setServices] = useState([])

  const [selection, setSelection] = useState(null)

  const [fTasks, setTasks] = useState([])

  useEffect(() => {
    setServices(array.union(fields[0].options, fields[1].options))
  }, [])
  
  const filterTasksByService = (service) => {
    setTasks(tasks.filter((t) => 
      t.custom_fields[0].enum_value !== null && t.custom_fields[0].enum_value.name === service
      || t.custom_fields[1].enum_value !== null && t.custom_fields[1].enum_value.name === service
    ))
  }

  const setSelect = (e) => {
    setSelection(e.currentTarget.value)
    filterTasksByService(e.currentTarget.value)
  }

  // Asssuming Asana structure doesn't change
  const getProductsAndDetails = (t) => {
    const prod1 = t.custom_fields[2].enum_value?.name
    const prod2 = t.custom_fields[3].enum_value?.name

    if (prod1 && prod2) {
      return prod1 + ', ' + prod2
    } else if (prod1) {
      return prod1
    } else if (prod2) {
      return prod2
    }

    return 'None'
  }
  
  return <>
    <div className="flex flex-col w-96">
      <label htmlFor="serviceSelect">Select Service:</label>
      <select onChange={setSelect} defaultValue="0">
        <option value="0" disabled>Select an option...</option>
        { services.map((s, idx) => (
          <option key={idx} value={s}> {s} </option>
        )) }
      </select>
    </div>
      { selection !== null ? <>
      <div className="mt-2 px-2 py-4 flex flex-col md:flex-row justify-center">
          { fTasks.length !== 0 ?
            <ol className="list-decimal list-inside">
              { fTasks.map((t, idx) => (
                <li className="px-2 my-4" key={idx}>
                  {t.name}
                  <ul className="list-disc list-inside px-2 py-2">
                    <li><strong className="font-bold">Reason: </strong> {t.custom_fields[4].text_value || 'None'} </li>
                    <li><strong className="font-bold">Impacted Products: </strong> {
                      getProductsAndDetails(t)
                    } </li>
                  </ul>
                </li>
              )) }
            </ol>
            : 'None' }
          <div className="w-full h-64 md:w-1/2">
            <ServiceProductChart atasks={fTasks} />
          </div>
      </div>
      </> : '' }
  </>
}

export default memo(ServiceInfo)